diff -ruN floating_ips.orig/tables.py floating_ips/tables.py
--- floating_ips.orig/tables.py	2012-11-30 23:01:55.000000000 +0100
+++ floating_ips/tables.py	2013-02-08 09:14:25.180478490 +0100
@@ -27,6 +27,7 @@
 from horizon import messages
 from horizon import tables
 
+from utils import get_int_or_uuid
 
 LOG = logging.getLogger(__name__)
 
@@ -82,7 +83,7 @@
 
     def single(self, table, request, obj_id):
         try:
-            fip = table.get_object_by_id(int(obj_id))
+            fip = table.get_object_by_id(get_int_or_uuid(obj_id))
             api.server_remove_floating_ip(request, fip.instance_id, fip.id)
             LOG.info('Disassociating Floating IP "%s".' % obj_id)
             messages.success(request,
@@ -117,7 +118,7 @@
                          empty_value="-")
 
     def sanitize_id(self, obj_id):
-        return int(obj_id)
+        return get_int_or_uuid(obj_id)
 
     def get_object_display(self, datum):
         return datum.ip
diff -ruN floating_ips.orig/utils.py floating_ips/utils.py
--- floating_ips.orig/utils.py	1970-01-01 01:00:00.000000000 +0100
+++ floating_ips/utils.py	2013-02-08 09:27:29.101693457 +0100
@@ -0,0 +1,31 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
+# Copyright 2012 NEC Corporation All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
+import uuid
+
+
+def get_int_or_uuid(value):
+ """Check if a value is valid as UUID or an integer.
+
+ This method is mainly used to convert floating IP id to the
+ appropriate type. For floating IP id, integer is used in Nova's
+ original implementation, but UUID is used in Quantum based one.
+ """
+ try:
+   uuid.UUID(value)
+   return value
+ except (ValueError, AttributeError):
+   return int(value)
diff -ruN floating_ips.orig/workflows.py floating_ips/workflows.py
--- floating_ips.orig/workflows.py	2012-11-30 23:01:55.000000000 +0100
+++ floating_ips/workflows.py	2013-02-08 09:14:25.180478490 +0100
@@ -23,13 +23,14 @@
 from horizon import workflows
 from horizon import forms
 
+from utils import get_int_or_uuid
 
 ALLOCATE_URL = "horizon:nova:access_and_security:floating_ips:allocate"
 
 
 class AssociateIPAction(workflows.Action):
     ip_id = forms.DynamicTypedChoiceField(label=_("IP Address"),
-                                          coerce=int,
+                                          coerce=get_int_or_uuid,
                                           empty_value=None,
                                           add_item_link=ALLOCATE_URL)
     instance_id = forms.ChoiceField(label=_("Instance"))
